==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/ko.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "요청 토큰을 가져올 수 없습니다. 앱 키와 비밀 값이 올바른지 확인하십시오.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "접근 토큰을 가져올 수 없습니다. 앱 키와 비밀 값이 올바른지 확인하십시오.",
    "Please provide a valid app key and secret." : "올바른 앱 키와 비밀 값을 입력하십시오.",
    "Step 1 failed. Exception: %s" : "1단계 실패. 예외: %s",
    "Step 2 failed. Exception: %s" : "2단계 실패. 예외: %s",
    "External storage" : "외부 저장소",
    "Dropbox App Configuration" : "Dropbox 앱 설정",
    "Google Drive App Configuration" : "구글 드라이브 앱 설정",
    "Personal" : "개인",
    "System" : "시스템",
    "Grant access" : "접근 권한 부여",
    "Error configuring OAuth1" : "OAuth1 설정 오류",
    "Error configuring OAuth2" : "OAuth2 설정 오류",
    "Generate keys" : "키 생성",
    "Error generating key pair" : "키 쌍을 생성하는 중 오류 발생",
    "All users. Type to select user or group." : "모든 사용자입니다. 사용자나 그룹을 선택하려면 입력하십시오",
    "(group)" : "(그룹)",
    "Admin defined" : "관리자 지정",
    "Saved" : "저장됨",
    "Save" : "저장",
    "Empty response from the server" : "서버에서 빈 응답이 돌아옴",
    "Couldn't access. Please logout and login to activate this mount point" : "접근할 수 없습니다. 이 마운트 지점을 활성화하려면 로그아웃 후 로그인하십시오",
    "Couldn't get the list of external mount points: {type}" : "외부 마운트 지점 목록을 가져올 수 없음: {type}",
    "There was an error with message: " : "오류 메시지: ",
    "External mount error" : "외부 마운트 오류",
    "external-storage" : "external-storage",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows 네트워크 드라이브 마운트 지점 목록을 가져올 수 없음: 서버에서 빈 응답이 돌아옴",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "일부 외부 마운트 지점을 연결할 수 없습니다. 빨간색으로 표시된 줄을 눌러서 더 많은 정보를 확인하십시오",
    "Please enter the credentials for the {mount} mount" : "{mount} 마운트 인증 정보를 입력하십시오",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Credentials saved" : "인증 정보 저장됨",
    "Credentials saving failed" : "인증 정보를 저장할 수 없음",
    "Credentials required" : "인증 정보 필요함",
    "Storage with id \"%i\" not found" : "ID가 \"%i\"인 저장소를 찾을 수 없음",
    "Invalid backend or authentication mechanism class" : "백엔드나 인증 방식 클래스가 잘못됨",
    "Invalid mount point" : "잘못된 마운트 지점",
    "Objectstore forbidden" : "Objectstore에 접근 금지됨",
    "Invalid storage backend \"%s\"" : "잘못된 저장소 백엔드 \"%s\"",
    "Not permitted to use backend \"%s\"" : "백엔드 \"%s\" 사용이 허가되지 않았음",
    "Not permitted to use authentication mechanism \"%s\"" : "인증 방식 \"%s\" 사용이 허가되지 않았음",
    "Unsatisfied backend parameters" : "백엔드 인자가 부족함",
    "Unsatisfied authentication mechanism parameters" : "인증 방식 인자가 부족함",
    "Insufficient data: %s" : "충분하지 않은 데이터: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "저장소 ID \"%i\"을(를) 사용자가 편집할 수 없음",
    "Access key" : "접근 키",
    "Secret key" : "비밀 키",
    "Builtin" : "내장",
    "None" : "없음",
    "OAuth1" : "OAuth1",
    "App key" : "앱 키",
    "App secret" : "앱 비밀 값",
    "OAuth2" : "OAuth2",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "OpenStack" : "OpenStack",
    "Tenant name" : "테넌트 이름",
    "Identity endpoint URL" : "아이덴티티 끝점(Endpoint) URL",
    "Rackspace" : "Rackspace",
    "API key" : "API 키",
    "Global credentials" : "글로벌 인증",
    "Log-in credentials, save in database" : "데이터베이스에 저장된 로그인 인증 정보",
    "Username and password" : "사용자 이름과 암호",
    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
    "User entered, store in database" : "사용자 데이터베이스에 저장",
    "RSA public key" : "RSA 공개 키",
    "Public key" : "공개 키",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "버킷",
    "Hostname" : "호스트 이름",
    "Port" : "포트",
    "Region" : "지역",
    "Enable SSL" : "SSL 사용",
    "Enable Path Style" : "경로 스타일 사용",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "원격 하위 폴더",
    "Secure https://" : "보안 https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "호스트",
    "Secure ftps://" : "보안 ftps://",
    "Google Drive" : "Google 드라이브",
    "Local" : "로컬",
    "Location" : "위치",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "루트",
    "SFTP with secret key login" : "비밀 키 로그인을 사용하는 SFTP",
    "SMB / CIFS" : "SMB/CIFS",
    "Share" : "공유",
    "Domain" : "도메인",
    "SMB / CIFS using OC login" : "OC 로그인을 사용하는 SMB/CIFS",
    "Username as share" : "사용자 이름으로 공유",
    "OpenStack Object Storage" : "OpenStack 객체 저장소",
    "Service name" : "서비스 이름",
    "Request timeout (seconds)" : "요청 시간 제한(초)",
    "External storages" : "외부 저장소",
    "No external storage configured" : "외부 저장소가 설정되지 않았음",
    "You can add external storages in the personal settings" : "개인 설정에서 외부 저장소를 추가할 수 있습니다",
    "Name" : "이름",
    "Storage type" : "저장소 종류",
    "Scope" : "범위",
    "Enable encryption" : "암호화 사용",
    "Enable previews" : "미리 보기 사용",
    "Enable sharing" : "공유 사용",
    "Check for changes" : "변경 사항 감시",
    "Never" : "하지 않음",
    "Once every direct access" : "한 번 직접 접근할 때마다",
    "Folder name" : "폴더 이름",
    "Authentication" : "인증",
    "Configuration" : "설정",
    "Available for" : "다음으로 사용 가능",
    "Add storage" : "저장소 추가",
    "Advanced settings" : "고급 설정",
    "Delete" : "삭제",
    "Allow users to mount external storage" : "사용자가 외부 저장소를 마운트하도록 허용",
    "Allow users to mount the following external storage" : "사용자가 다음 외부 저장소를 마운트할 수 있도록 허용",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud 서버에서 정보를 가져올 수 없음: {code} {type}",
    "Access granted" : "접근 부여",
    "Global Credentials" : "글로벌 자격 증명",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>메모:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>메모:</b> PHP cURL 모듈이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>메모:</b> PHP FTP 모듈이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>메모:</b> \"%s\"이(가) 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "External Storage" : "외부 저장소"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/files_external/l10n/ko.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "외부 저장소",
    "Personal" : "개인",
    "System" : "시스템",
    "Grant access" : "접근 권한 부여",
    "Error configuring OAuth1" : "OAuth1 설정 오류",
    "Please provide a valid app key and secret." : "올바른 앱 키와 비밀 값을 입력하십시오.",
    "Error configuring OAuth2" : "OAuth2 설정 오류",
    "Generate keys" : "키 생성",
    "Error generating key pair" : "키 쌍을 생성하는 중 오류 발생",
    "All users. Type to select user or group." : "모든 사용자입니다. 사용자나 그룹을 선택하려면 입력하십시오.",
    "(group)" : "(그룹)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD 인코딩 호환성 사용(느림)",
    "Admin defined" : "관리자 지정",
    "Delete storage?" : "저장소를 삭제하시겠습니까?",
    "Saved" : "저장됨",
    "Saving..." : "저장 중...",
    "Save" : "저장",
    "Empty response from the server" : "서버에서 빈 응답이 돌아옴",
    "Couldn't access. Please log out and in again to activate this mount point" : "접속할 수 없습니다. 이 마운트 지점을 활성화하기 위해 로그아웃 후 다시 로그인 해 주세요",
    "Couldn't get the information from the remote server: {code} {type}" : "원격 서버에서 정보를 가져올 수 없음: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "외부 마운트 지점 목록을 가져올 수 없음: {type}",
    "There was an error with message: " : "오류 메시지: ",
    "External mount error" : "외부 마운트 오류",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Windows 네트워크 드라이브 마운트 지점 목록을 가져올 수 없음: 서버에서 빈 응답이 돌아옴",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "일부 외부 마운트 지점을 연결할 수 없습니다. 빨간색으로 표시된 줄을 눌러서 더 많은 정보를 확인하십시오",
    "Please enter the credentials for the {mount} mount" : "{mount} 마운트 인증 정보를 입력하십시오",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Credentials saved" : "인증 정보 저장됨",
    "Credentials saving failed" : "인증 정보를 저장할 수 없음",
    "Credentials required" : "인증 정보 필요함",
    "Storage with ID \"%d\" not found" : "ID \"%d\"인 공유를 찾을 수 없음",
    "Invalid backend or authentication mechanism class" : "백엔드나 인증 방식 클래스가 잘못됨",
    "Invalid mount point" : "잘못된 마운트 지점",
    "Objectstore forbidden" : "Objectstore에 접근 금지됨",
    "Invalid storage backend \"%s\"" : "잘못된 저장소 백엔드 \"%s\"",
    "Not permitted to use backend \"%s\"" : "백엔드 \"%s\" 사용이 허가되지 않았음",
    "Not permitted to use authentication mechanism \"%s\"" : "인증 방식 \"%s\" 사용이 허가되지 않았음",
    "Unsatisfied backend parameters" : "백엔드 인자가 부족함",
    "Unsatisfied authentication mechanism parameters" : "인증 방식 인자가 부족함",
    "Insufficient data: %s" : "충분하지 않은 데이터: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "저장소 ID \"%d\"을(를) 사용자가 편집할 수 없음",
    "Access key" : "접근 키",
    "Secret key" : "비밀 키",
    "Builtin" : "내장",
    "None" : "없음",
    "OAuth1" : "OAuth1",
    "App key" : "앱 키",
    "App secret" : "앱 비밀 값",
    "OAuth2" : "OAuth2",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "Tenant name" : "테넌트 이름",
    "Identity endpoint URL" : "아이덴티티 끝점(Endpoint) URL",
    "Domain" : "도메인",
    "Rackspace" : "Rackspace",
    "API key" : "API 키",
    "Global credentials" : "글로벌 인증",
    "Log-in credentials, save in database" : "데이터베이스에 저장된 로그인 인증 정보",
    "Username and password" : "사용자 이름과 암호",
    "Log-in credentials, save in session" : "로그인 인증 정보, 세션에 저장됨",
    "User entered, store in database" : "사용자 데이터베이스에 저장",
    "RSA public key" : "RSA 공개 키",
    "Public key" : "공개 키",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "버킷",
    "Hostname" : "호스트 이름",
    "Port" : "포트",
    "Region" : "지역",
    "Enable SSL" : "SSL 사용",
    "Enable Path Style" : "경로 스타일 사용",
    "Legacy (v2) authentication" : "레거시(v2) 인증",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "원격 하위 폴더",
    "Secure https://" : "보안 https://",
    "FTP" : "FTP",
    "Host" : "호스트",
    "Secure ftps://" : "보안 ftps://",
    "Local" : "로컬",
    "Location" : "위치",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "루트",
    "SFTP with secret key login" : "비밀 키 로그인을 사용하는 SFTP",
    "SMB / CIFS" : "SMB/CIFS",
    "Share" : "공유",
    "SMB / CIFS using OC login" : "OC 로그인을 사용하는 SMB/CIFS",
    "Username as share" : "사용자 이름으로 공유",
    "OpenStack Object Storage" : "OpenStack 객체 저장소",
    "Service name" : "서비스 이름",
    "Request timeout (seconds)" : "요청 시간 제한(초)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP의 cURL 지원이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHP의 FTP 지원이 비활성화되어 있거나 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"이(가) 설치되어 있지 않습니다. %s을(를) 마운트할 수 없습니다. 시스템 관리자에게 설치를 요청하십시오.",
    "Name" : "이름",
    "Storage type" : "저장소 종류",
    "Scope" : "범위",
    "Enable encryption" : "암호화 사용",
    "Enable previews" : "미리 보기 사용",
    "Enable sharing" : "공유 사용",
    "Check for changes" : "변경 사항 감시",
    "Never" : "하지 않음",
    "Once every direct access" : "한 번 직접 접근할 때마다",
    "Folder name" : "폴더 이름",
    "External storage" : "외부 저장소",
    "Authentication" : "인증",
    "Configuration" : "설정",
    "Available for" : "다음으로 사용 가능",
    "Add storage" : "저장소 추가",
    "Advanced settings" : "고급 설정",
    "Delete" : "삭제",
    "Allow users to mount external storage" : "사용자가 외부 저장소를 마운트하도록 허용",
    "Allow users to mount the following external storage" : "사용자가 다음 외부 저장소를 마운트할 수 있도록 허용",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "요청 토큰을 가져올 수 없습니다. 앱 키와 비밀 값이 올바른지 확인하십시오.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "접근 토큰을 가져올 수 없습니다. 앱 키와 비밀 값이 올바른지 확인하십시오.",
    "Step 1 failed. Exception: %s" : "1단계 실패. 예외: %s",
    "Step 2 failed. Exception: %s" : "2단계 실패. 예외: %s",
    "Dropbox App Configuration" : "Dropbox 앱 설정",
    "Google Drive App Configuration" : "Google 드라이브 앱 설정",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google 드라이브",
    "No external storage configured" : "외부 저장소가 설정되지 않았음",
    "You can add external storages in the personal settings" : "개인 설정에서 외부 저장소를 추가할 수 있습니다",
    "Are you sure you want to delete this external storage" : "이 외부 저장소를 삭제하시겠습니까"
},
"nplurals=1; plural=0;");
